@@ -37,7 +37,6 @@ __all__ = [
     "FileResponse",
     "RedirectResponse",
     "StreamingResponse",
-    "ReturnValue",
 ]
 
 
@@ -53,4 +52,3 @@ Body = typing.NewType("Body", bytes)
 PathParams = typing.NewType("PathParams", dict)
 PathParam = typing.NewType("PathParam", str)
 RequestData = typing.TypeVar("RequestData")
-ReturnValue = typing.TypeVar("ReturnValue")
